import React from 'react'

import MCF_Autocomplete from './components/MCF_AutoComplete'
import MCF_Button from './components/MCF_Button'
import MCF_Card from './components/MCF_Card'
import MCF_Checkbox from './components/MCF_Checkbox'
import MCF_CheckboxesGroup from './components/MCF_CheckboxesGroup'
import MCF_Dialog from './components/MCF_Dialog'
import MCF_Divider from './components/MCF_Divider'
import MCF_FileUpload from './components/MCF_FileUpload'
import MCF_MediaCard from './components/MCF_MediaCard'
import MCF_Select from './components/MCF_Select'
import MCF_Text from './components/MCF_Text'



export default class ComponentFactory {
  static createComponent(componentConfig) {
    const params = componentConfig.params
    params.key = params.parentKey !== undefined ? params.parentKey + params.id : params.id

    switch (componentConfig.type) {
    case 'autocomplete':
      return <MCF_Autocomplete key={params.key} params={params}/>
    case 'button':
      return <MCF_Button key={params.key} params={params}/>
    case 'card':
      return <MCF_Card key={params.key} params={params}/>
    case 'checkbox':
      return <MCF_Checkbox key={params.key} params={params}/>
    case 'checkboxesGroup':
      return <MCF_CheckboxesGroup key={params.key} params={params}/>
    case 'dialog':
      return <MCF_Dialog key={params.key} params={params}/>
    case 'divider':
      return <MCF_Divider key={params.key} params={params}/>
    case 'fileUpload':
      return <MCF_FileUpload key={params.key} params={params}/>
    case 'mediaCard':
      return <MCF_MediaCard key={params.key} params={params}/>
    case 'select':
      return <MCF_Select key={params.key} params={params}/>
    case 'text':
      return <MCF_Text key={params.key} params={params}/>
    default:
      throw new Error(`MCF-Components ==> The component type ${componentConfig.type} does not exist. Check the component config with id ${componentConfig.params.id}`)
    }
  }
}
