/* eslint-disable react/prop-types */

import React, {useState} from 'react'

import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import DialogActions from '@material-ui/core/DialogActions'
import DialogContent from '@material-ui/core/DialogContent'
import DialogContentText from '@material-ui/core/DialogContentText'
import DialogTitle from '@material-ui/core/DialogTitle'

import ComponentFactory from '../ComponentFactory'



export default function MCF_Dialog (props) {
  const [params, setParams] = useState(props.params)

  const handleOpen = () => {
    setParams({...params, open: true})
    if (params.openListener) {
      params.openListener()
    }
  }
  const handleClose = () => {
    setParams({...params, open: false})
    if (params.closeListener) {
      params.closeListener()
    }
  }

  const renderContents = () => {
    return params.contents.map(contentParams => {
      contentParams.params.parentParams = params
      contentParams.params.parentParams.handleClose = handleClose
      contentParams.params.parentParams.handleClickOpen = handleOpen
      contentParams.params.parentKey = params.key
      contentParams.setParentParams = setParams
      return ComponentFactory.createComponent(contentParams)
    })
  }

  const renderActionContents = () => {
    return params.actionContents.map(contentParams => {
      contentParams.params.parentParams = params
      contentParams.params.parentParams.handleClose = handleClose
      contentParams.params.parentParams.handleClickOpen = handleOpen
      contentParams.params.parentKey = params.key
      contentParams.setParentParams = setParams
      return ComponentFactory.createComponent(contentParams)
    })
  }

  return (
    <div>
      <Button
        variant={params.openButtonVariant}  // 'contained' | 'outlined' | 'text'
        color={params.openButtonColor}  // 'default' | 'inherit' | 'primary' | 'secondary'
        onClick={handleOpen}>
        {params.openButtonText/* string */}
      </Button>
      <Dialog
        open={params.open}  // boolean
        onClose={handleClose}
        aria-labelledby={params.id}
      >
        <DialogTitle id={params.id/* string */}>
          {params.titleText/* string */}
        </DialogTitle>
        <DialogContent>
          <DialogContentText>
            {params.contentText/* string */}
          </DialogContentText>
          {renderContents()}
        </DialogContent>
        <DialogActions>
          {renderActionContents()}
          <Button
            variant={params.closeButtonVariant}  // 'contained' | 'outlined' | 'text'
            color={params.closeButtonColor}  // 'default' | 'inherit' | 'primary' | 'secondary'
            onClick={handleClose}>
            {params.closeButtonText/* string */}
          </Button>
        </DialogActions>
      </Dialog>
    </div>
  )
}
