/* eslint-disable react/prop-types */

import React, {useState, useEffect} from 'react'

import Button from '@material-ui/core/Button'

import {useStyles} from '../index'



export default function MCF_FileUpload (props) {
  const [params, setParams] = useState(props.params)
  const classes = useStyles()

  if (params.acceptedFormats === undefined) params.acceptedFormats = '*!/!*'

  useEffect(() => {
    const input = document.getElementById(params.id)

    input.addEventListener('change', event => {
      event.preventDefault()

      const files = document.querySelector('input[type=file]').files
      if (files.length > 0) {
        const formData = new FormData()
        formData.append('tkn', params.token)
        if (params.storagePath) formData.append('path', params.storagePath)
        for (let i = 0; i < files.length; i++) {
          formData.append('files[]', files[i])
        }

        if (params.beforeFetchListener) params.beforeFetchListener(files)

        fetch(params.url, {
          method: 'POST',
          body: formData,
        }).then(response => {
          if (response) params.files = files
          handleUploadSuccess(response)
        })
          .catch(error => handleUploadError(error))
      }
    })
  }, [])
  
  const handleUploadSuccess = response => {
    if (params.onUpload) params.onUpload(response, params.files)
    setParams(params)
  }

  const handleUploadError = error => {
    if (params.onError) params.onError(error)
    params.files = null
  }

  return (
    <div>
      <input
        id={params.id}  // string
        className={classes.input}
        accept={params.acceptedFormats}  // strings array
        multiple
        type="file"
      />
      <label htmlFor={params.id}>
        <Button
          className={classes.button}
          color={params.color}  // 'default' | 'inherit' | 'primary' | 'secondary'
          size={params.size}  // 'large' | 'medium' | 'small'
          variant={params.variant}  // 'contained' | 'outlined' | 'text'
          component="span">
          {params.text}
        </Button>
      </label>
    </div>
  )
}
